@@ -1,6 +1,6 @@
 use super::*;
 
-// https://tailwindcss.com/docs/background-origin
+#[doc=include_str!("readme.md")]
 #[derive(Clone, Debug)]
 pub struct TailwindBackgroundPosition {
     kind: AnchorPoint,
@@ -13,7 +13,7 @@ impl Display for TailwindBackgroundPosition {
 }
 
 impl TailwindInstance for TailwindBackgroundPosition {
-    fn attributes(&self, _: &TailwindBuilder) -> BTreeSet<CssAttribute> {
+    fn attributes(&self, _: &TailwindBuilder) -> CssAttributes {
         css_attributes! {
             "transform-origin" => self.kind.get_properties()
         }
