@@ -1,5 +1,12 @@
 use super::*;
 
+#[doc=include_str!("readme.md")]
+#[derive(Copy, Clone, Debug)]
+pub struct TailwindRounded {
+    kind: RoundedKind,
+    size: LengthUnit,
+}
+
 #[derive(Copy, Clone, Debug)]
 enum RoundedKind {
     Rounded,
@@ -13,12 +20,6 @@ enum RoundedKind {
     RoundedBR,
 }
 
-#[derive(Copy, Clone, Debug)]
-pub struct TailwindRounded {
-    kind: RoundedKind,
-    size: LengthUnit,
-}
-
 impl Display for RoundedKind {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
         match self {
@@ -42,7 +43,7 @@ impl Display for TailwindRounded {
 }
 
 impl TailwindInstance for TailwindRounded {
-    fn attributes(&self, _: &TailwindBuilder) -> BTreeSet<CssAttribute> {
+    fn attributes(&self, _: &TailwindBuilder) -> CssAttributes {
         let size = format!("{:?}", self.size);
         match self.kind {
             RoundedKind::Rounded => css_attributes! {
