@@ -6,11 +6,7 @@ pub struct TailwindRingColor {
     color: TailwindColor,
 }
 
-impl From<TailwindColor> for TailwindRingColor {
-    fn from(color: TailwindColor) -> Self {
-        Self { color }
-    }
-}
+crate::macros::sealed::color_instance!(TailwindRingColor);
 
 impl Display for TailwindRingColor {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
@@ -19,7 +15,7 @@ impl Display for TailwindRingColor {
 }
 
 impl TailwindInstance for TailwindRingColor {
-    fn attributes(&self, ctx: &TailwindBuilder) -> BTreeSet<CssAttribute> {
+    fn attributes(&self, ctx: &TailwindBuilder) -> CssAttributes {
         css_attributes! {
             "--tw-ring-color" => self.color.get_properties(ctx)
         }
