@@ -6,11 +6,7 @@ pub struct TailwindRingOffsetColor {
     color: TailwindColor,
 }
 
-impl From<TailwindColor> for TailwindRingOffsetColor {
-    fn from(color: TailwindColor) -> Self {
-        Self { color }
-    }
-}
+crate::macros::sealed::color_instance!(TailwindRingOffsetColor);
 
 impl Display for TailwindRingOffsetColor {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
@@ -19,19 +15,10 @@ impl Display for TailwindRingOffsetColor {
 }
 
 impl TailwindInstance for TailwindRingOffsetColor {
-    fn attributes(&self, ctx: &TailwindBuilder) -> BTreeSet<CssAttribute> {
+    fn attributes(&self, ctx: &TailwindBuilder) -> CssAttributes {
         css_attributes! {
             "--tw-ring-offset-color" => self.color.get_properties(ctx),
             "box-shadow" => "0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color), var(--tw-ring-shadow)"
         }
     }
 }
-
-impl TailwindRingOffsetColor {
-    pub fn parse(input: &[&str], arbitrary: &TailwindArbitrary) -> Result<Self> {
-        Ok(Self { color: TailwindColor::parse(input, arbitrary)? })
-    }
-    pub fn parse_arbitrary(arbitrary: &TailwindArbitrary) -> Result<Self> {
-        Ok(Self { color: TailwindColor::parse_arbitrary(arbitrary)? })
-    }
-}
