@@ -1,13 +1,10 @@
-use std::{
-    collections::BTreeSet,
-    fmt::{Display, Formatter},
-};
+use std::fmt::{Display, Formatter};
 
 pub use self::{
     box_color::TailwindShadowColor, box_shadow::TailwindShadow, mix_blend::TailwindBlend,
     mix_blend_bg::TailwindBackgroundBlend, opacity::TailwindOpacity,
 };
-use crate::{css_attributes, syntax_error, CssAttribute, Result, TailwindArbitrary, TailwindBuilder, TailwindInstance};
+use crate::{css_attributes, syntax_error, CssAttributes, Result, TailwindArbitrary, TailwindBuilder, TailwindInstance};
 
 mod box_color;
 mod box_shadow;
