@@ -28,7 +28,7 @@ impl Display for TailwindFlexWrap {
 }
 
 impl TailwindInstance for TailwindFlexWrap {
-    fn attributes(&self, _: &TailwindBuilder) -> BTreeSet<CssAttribute> {
+    fn attributes(&self, _: &TailwindBuilder) -> CssAttributes {
         css_attributes! {
             "flex-wrap" => self.kind
         }
