@@ -1,3 +1,4 @@
+
 use self::scroll_behavior::TailwindScrollBehavior;
 use super::*;
 pub(crate) mod scroll_behavior;
@@ -7,7 +8,8 @@ pub(crate) mod scroll_behavior;
 pub struct TailwindScroll {}
 
 impl TailwindScroll {
-    pub fn parse(pattern: &[&str], arbitrary: &TailwindArbitrary, negative: bool) -> Result<Box<dyn TailwindInstance>> {
+    /// <https://tailwindcss.com/docs/scroll-behavior>
+    pub fn parse(pattern: &[&str], arbitrary: &TailwindArbitrary, negative: Negative) -> Result<Box<dyn TailwindInstance>> {
         let kind = match pattern {
             ["p" | "pl" | "pr" | "pb" | "pt" | "px" | "py", ..] =>
                 TailwindScrollPadding::parse(pattern, arbitrary, negative)?.boxed(),
