@@ -11,7 +11,7 @@ impl Display for TailwindContainer {
 }
 
 impl TailwindInstance for TailwindContainer {
-    fn attributes(&self, _: &TailwindBuilder) -> BTreeSet<CssAttribute> {
-        BTreeSet::new()
+    fn attributes(&self, _: &TailwindBuilder) -> CssAttributes {
+        css_attributes! {}
     }
 }
