@@ -26,7 +26,7 @@ impl Display for TailwindIsolation {
 }
 
 impl TailwindInstance for TailwindIsolation {
-    fn attributes(&self, _: &TailwindBuilder) -> BTreeSet<CssAttribute> {
+    fn attributes(&self, _: &TailwindBuilder) -> CssAttributes {
         css_attributes! {
             "isolation" => self.kind
         }
