@@ -1,10 +1,10 @@
 use std::{
     collections::BTreeSet,
-    fmt::{Debug, Display, Formatter, Write},
+    fmt::{Debug, Display, Formatter},
 };
 
 use crate::{
-    css_attributes, syntax_error, CssAttribute, Result, SpacingAxis, TailwindArbitrary, TailwindBuilder, TailwindInstance,
+    css_attributes, syntax_error, CssAttributes, Result, SpacingAxis, TailwindArbitrary, TailwindBuilder, TailwindInstance,
 };
 
 use self::size::SpacingSize;
@@ -12,7 +12,7 @@ pub use self::{
     margin::TailwindMargin, margin_scroll::TailwindScrollMargin, padding::TailwindPadding,
     padding_scroll::TailwindScrollPadding, space::TailwindSpace, space_reverse::TailwindSpaceReverse,
 };
-
+use crate::Negative;
 mod margin;
 mod margin_scroll;
 mod padding;
