@@ -3,12 +3,9 @@ pub use self::{
     stroke::{stroke_color::TailwindStrokeColor, stroke_width::TailwindStrokeWidth, TailwindStroke},
 };
 use crate::{
-    css_attributes, CssAttribute, LengthUnit, Result, TailwindArbitrary, TailwindBuilder, TailwindColor, TailwindInstance,
-};
-use std::{
-    collections::BTreeSet,
-    fmt::{Display, Formatter},
+    css_attributes, CssAttributes, LengthUnit, Result, TailwindArbitrary, TailwindBuilder, TailwindColor, TailwindInstance,
 };
+use std::fmt::{Display, Formatter};
 
 mod fill;
 mod stroke;
