@@ -14,13 +14,6 @@ impl From<&str> for TailwindArbitrary {
 
 impl Display for TailwindArbitrary {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
-        match self.inner.is_empty() {
-            true => {
-                write!(f, "")
-            },
-            false => {
-                write!(f, "-[{}]", self.inner)
-            },
-        }
+        write!(f, "{}", self.inner)
     }
 }
