@@ -1,5 +1,3 @@
-use std::collections::BTreeSet;
-
 use log::error;
 
 use super::*;
@@ -9,9 +7,7 @@ impl Display for TailwindInstruction {
         for v in &self.variants {
             write!(f, "{}", v)?
         }
-        if self.negative {
-            write!(f, "-")?
-        }
+        self.negative.write(f)?;
         match self.arbitrary.is_some() {
             true => write!(f, "{}-[{}]", self.elements, self.arbitrary),
             false => write!(f, "{}", self.elements),
@@ -20,8 +16,8 @@ impl Display for TailwindInstruction {
 }
 
 impl TailwindInstance for TailwindInstruction {
-    fn attributes(&self, ctx: &TailwindBuilder) -> BTreeSet<CssAttribute> {
-        let mut out = BTreeSet::default();
+    fn attributes(&self, ctx: &TailwindBuilder) -> CssAttributes {
+        let mut out = CssAttributes::default();
         match self.get_instance() {
             Ok(o) => out.extend(o.attributes(ctx)),
             Err(e) => {
