@@ -11,16 +11,10 @@ use std::{
 };
 use tailwind_ast::{parse_f32, parse_fraction, parse_integer, ASTVariant, AstStyle};
 
-#[cfg(test)]
-pub fn tw_idempotency(input1: &str, builder: &mut TailwindBuilder) {
-    let input2 = &builder.trace(input1);
-    assert_eq!(builder.inline(input1), builder.inline(input2))
-}
-
 /// `v:v:-a-a-[A]`
 #[derive(Debug, Clone)]
 pub struct TailwindInstruction {
-    negative: bool,
+    negative: Negative,
     variants: Vec<TailwindVariant>,
     elements: TailwindElements,
     arbitrary: TailwindArbitrary,
