@@ -57,13 +57,13 @@ impl TailwindInstruction {
             ["visible"] => TailwindVisibility::from("visible").boxed(),
             ["invisible"] => TailwindVisibility::from("hidden").boxed(),
             // https://tailwindcss.com/docs/z-index
-            ["z", rest @ ..] => TailwindZIndex::parse(rest, arbitrary, self.negative)?.boxed(),
+            ["z", rest @ ..] => TailwindZIndex::parse(rest, arbitrary, neg)?.boxed(),
             // Flexbox & Grid
             ["basis", rest @ ..] => TailwindBasis::parse(rest, arbitrary)?.boxed(),
             ["flex", rest @ ..] => TailwindFlex::adapt(rest, arbitrary)?,
             ["grow", rest @ ..] => TailWindGrow::parse(rest, arbitrary)?.boxed(),
             ["shrink", rest @ ..] => TailWindShrink::parse(rest, arbitrary)?.boxed(),
-            ["order", rest @ ..] => TailWindOrder::parse(rest, arbitrary, self.negative)?.boxed(),
+            ["order", rest @ ..] => TailWindOrder::parse(rest, arbitrary, neg)?.boxed(),
             ["grid", rest @ ..] => TailwindGrid::adapt(rest, arbitrary)?,
             // https://tailwindcss.com/docs/grid-column
             ["col", rest @ ..] => TailwindColumn::parse(rest, arbitrary)?.boxed(),
@@ -139,7 +139,7 @@ impl TailwindInstruction {
             // Borders System
             ["rounded", rest @ ..] => TailwindRounded::parse(rest, arbitrary)?.boxed(),
             ["border", rest @ ..] => TailwindBorder::adapt(rest, arbitrary)?,
-            ["divide", rest @ ..] => TailwindDivide::parse(rest, arbitrary)?,
+            ["divide", rest @ ..] => TailwindDivide::adapt(rest, arbitrary)?,
             ["outline", rest @ ..] => TailwindOutline::adapt(rest, arbitrary)?,
             ["ring", rest @ ..] => TailwindRing::adapt(rest, arbitrary)?,
             // Effects System
@@ -238,8 +238,8 @@ impl TailwindInstruction {
             // https://tailwindcss.com/docs/box-decoration-break
             ["decoration", rest @ ..] => TailwindBoxDecoration::parse(rest, arbitrary)?.boxed(),
 
-            ["border"] => TailwindBoxSizing::from("border").boxed(),
-            ["content"] => TailwindBoxSizing::from("content").boxed(),
+            ["border"] => TailwindBoxSizing::from("border-box").boxed(),
+            ["content"] => TailwindBoxSizing::from("content-box").boxed(),
             _ => return syntax_error!("Unknown box instructions: {}", str.join("-")),
         };
         Ok(out)
